package org.purl.jh.esslli;

import org.purl.jh.esslli.data.Lt;
import com.google.common.base.Charsets;
import com.google.common.base.Preconditions;
import com.google.common.io.Files;
import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Collection;

/**
 * The main class of the system to be called from the command line.
 */
public class Ma {
    private Analyser analyzer;

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        new Ma().go(args);
    }

    private void go(String[] args) {
        Preconditions.checkArgument(args.length == 3, "Expecting <lgSpecdir> <inFile> <outFile> " + args.length);
        
        File lgDir   = new File(args[0]);
        File inFile  = new File(args[1]);
        File outFile = new File(args[2]);
        
        setupMorph(lgDir);
        
        try {
            analyze(inFile, outFile);
        } catch (IOException ex) {
            System.err.println(ex);
        }
    }

    private void setupMorph(File lgDir) {
        analyzer = new MapAnalyser.Compiler().compile(new File(lgDir, "map.spec"));
    }

    private void analyze(File inFile, File outFile) throws IOException {
        try (final PrintWriter w = new PrintWriter(Files.newWriter(outFile, Charsets.UTF_8))) {
            for (String form : Files.readLines(inFile, Charsets.UTF_8)) {
                Collection<Lt> lts = this.analyzer.analyze(form);
                write(w, form, lts);
            }        
        }
    }

    private void write(PrintWriter w, String form, Collection<Lt> lts) {
        w.println(form);
        for (Lt lt : lts) {
            w.print("\t");
            w.print(lt.lemma);
            w.print("\t");
            w.println(lt.tag);
        }
    }
}
