package org.purl.jh.esslli.util;

import java.io.File;

/**
 * User or Internal Format exception
 */
public class FormatException extends XException {
    /**
     * Format error with information about a file it occurred in.
     *
     * @param aFile file where the error occurred 
     * @param aLine line where the error occurred; set to -1 if unknown
     * @param aCol  column where the error occurred; set to -1 if unknown (currently ignored!)
     * @param aFormat template for the error message
     * @param aParams filler strings for the template
     */
    public FormatException(File aFile, int aLine, int aCol, String aFormat, Object ... aParams) {
        super("[" + aLine + ":" + aFormat + "]: " + aFormat, aParams);
    }

    
    public FormatException(String aFormat, Object ... aParams) {
        super(aFormat, aParams);
    }
    
    public FormatException(Throwable aCause) {
        super(aCause);
    }

    public FormatException(Throwable aCause, String aFormat, Object ... aParams) {
        super(aCause, aFormat, aParams);
    }
}
